    Possible Commands                   |      Output

1.   m1key -h                           |  Help
2.   m1key -i                           |  Introduction
3.   m1key -t                           |  Gives Tree structure of all commands
4.   m1key -w                           |  Takes you to my portfolio website
5.   m1key project -h                   |  Gives help commands about project
6.   m1key project -s image _location   |  Produces an image by extracting the 2 dominant colors of given image
7.   m1key project -t                   |  Opens up the camera and puts a prop on your face in realtime.
8.   m1key project -o                   |  Take you to oneml website, which is platform where one can visualize ML algos.
9.   m1key resume -d                    |  Download Resume
10.  m1key skills / m1key skills -a     |  List down all my skills
11.  m1key education -a                 |  List down all my educational reports    